JSTimeout class

Constructors

JSTimeout(VoidCallback function, int milliseconds)

Properties

function → VoidCallback
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
no setter
milliseconds → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
emit() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited